# minimal_hatch_project

[![PyPI - Version](https://img.shields.io/pypi/v/minimal-hatch-project.svg)](https://pypi.org/project/minimal-hatch-project)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/minimal-hatch-project.svg)](https://pypi.org/project/minimal-hatch-project)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install minimal-hatch-project
```

## License

`minimal-hatch-project` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
